@@ -28,7 +28,7 @@ urllib3.disable_warnings()
 class CGDB:
     """Client class for communication with CGDB
     """
-    def __init__(self, api_key, host=None, debug=False):
+    def __init__(self, api_key, host=None, debug_post=False, debug_get=False):
         """ :type api_key: str
             :param api_key: api key for authenticate to api endpoint
 
@@ -51,7 +51,8 @@ class CGDB:
         self._aggregations_manager = AggregationsManager()
         self._station_groups_manager = StationGroupsManager(client=self)
         self._levels_manager = LevelsManager(client=self)
-        cgdb.config.DEBUG_CONSOLE_LOG_CGDB_LIB = debug
+        cgdb.config.DEBUG_CONSOLE_LOG_CGDB_LIB_GET = debug_get
+        cgdb.config.DEBUG_CONSOLE_LOG_CGDB_LIB_POST = debug_post
 
 
     def sites(self):
