@@ -273,7 +273,7 @@ class DataSetsManager(ManagerMix):
         if overwriteStrategy is not None:
             url += "?overwriteStrategy=" + overwriteStrategy
 
-        a = self._client._session.post(url, data=out)
+        a = self.post(url, data=out)
         if a.status_code != 200:
             raise Exception("upload fail on server side " + a.text)
 
