@@ -1,4 +1,4 @@
-from cgdb.recources.stationNetwork import StationNetwork
+from cgdb.resources.stationNetwork import StationNetwork
 from cgdb.utils.ManagerMix import ManagerMix
 
 class StationNetworksManager(ManagerMix):
